@@ -35,7 +35,8 @@ struct _GdMainViewPrivate {
   GtkWidget *current_view;
   GtkTreeModel *model;
 
-  gchar *button_press_item_path;
+  gdouble button_press_x;
+  gdouble button_press_y;
 };
 
 enum {
@@ -67,16 +68,6 @@ gd_main_view_dispose (GObject *obj)
   G_OBJECT_CLASS (gd_main_view_parent_class)->dispose (obj);
 }
 
-static void
-gd_main_view_finalize (GObject *obj)
-{
-  GdMainView *self = GD_MAIN_VIEW (obj);
-
-  g_free (self->priv->button_press_item_path);
-
-  G_OBJECT_CLASS (gd_main_view_parent_class)->finalize (obj);
-}
-
 static void
 gd_main_view_init (GdMainView *self)
 {
@@ -156,7 +147,6 @@ gd_main_view_class_init (GdMainViewClass *klass)
   oclass->get_property = gd_main_view_get_property;
   oclass->set_property = gd_main_view_set_property;
   oclass->dispose = gd_main_view_dispose;
-  oclass->finalize = gd_main_view_finalize;
 
   properties[PROP_VIEW_TYPE] =
     g_param_spec_int ("view-type",
@@ -378,7 +368,6 @@ on_button_release_event (GtkWidget *view,
   GdMainView *self = user_data;
   GdMainViewGeneric *generic = get_generic (self);
   GtkTreePath *path;
-  gchar *button_release_item_path;
   gboolean entered_mode = FALSE, selection_mode;
   gboolean res, same_item = FALSE;
 
@@ -390,15 +379,12 @@ on_button_release_event (GtkWidget *view,
 
   if (path != NULL)
     {
-      button_release_item_path = gtk_tree_path_to_string (path);
-      if (g_strcmp0 (self->priv->button_press_item_path, button_release_item_path) == 0)
+      if (event->x == self->priv->button_press_x &&
+          event->y == self->priv->button_press_y)
         same_item = TRUE;
-
-      g_free (button_release_item_path);
     }
 
-  g_free (self->priv->button_press_item_path);
-  self->priv->button_press_item_path = NULL;
+  self->priv->button_press_x = self->priv->button_press_y = 0;
 
   if (!same_item)
     {
@@ -440,11 +426,21 @@ on_button_press_event (GtkWidget *view,
   GList *selection, *l;
   GtkTreePath *sel_path;
   gboolean found = FALSE;
+  gdouble event_x = 0, event_y = 0;
+
+  self->priv->button_press_x = event->x;
+  self->priv->button_press_y = event->y;
 
   path = gd_main_view_generic_get_path_at_pos (generic, event->x, event->y);
 
   if (path != NULL)
-    self->priv->button_press_item_path = gtk_tree_path_to_string (path);
+    {
+      event_x = event->x;
+      event_y = event->y;
+    }
+
+  self->priv->button_press_x = event_x;
+  self->priv->button_press_y = event_y;
 
   if (!self->priv->selection_mode ||
       path == NULL)
@@ -480,15 +476,18 @@ on_drag_begin (GdMainViewGeneric *generic,
                gpointer user_data)
 {
   GdMainView *self = user_data;
+  GtkTreePath *path;
 
-  if (self->priv->button_press_item_path != NULL)
+  path = gd_main_view_generic_get_path_at_pos (generic,
+                                               self->priv->button_press_x,
+                                               self->priv->button_press_y);
+
+  if (path != NULL)
     {
       gboolean res;
       GtkTreeIter iter;
       GdkPixbuf *icon = NULL;
-      GtkTreePath *path;
 
-      path = gtk_tree_path_new_from_string (self->priv->button_press_item_path);
       res = gtk_tree_model_get_iter (self->priv->model,
                                      &iter, path);
       if (res)
