@@ -91,6 +91,8 @@ MainWindow.prototype = {
 
         Global.modeController.connect('fullscreen-changed',
                                       Lang.bind(this, this._onFullscreenChanged));
+        Global.modeController.connect('window-mode-changed',
+                                      Lang.bind(this, this._onWindowModeChanged));
 
         // the base layout is a vertical ClutterBox
         this._clutterBoxLayout = new Clutter.BoxLayout({ vertical: true });
@@ -156,6 +158,11 @@ MainWindow.prototype = {
         Global.settings.set_boolean('window-maximized', maximized);
     },
 
+    _onWindowModeChanged: function() {
+        if (Global.modeController.getWindowMode() == WindowMode.WindowMode.PREVIEW)
+            this._searchbar.hide();
+    },
+
     _onFullscreenChanged: function(controller, fullscreen) {
         if (fullscreen)
             this.window.fullscreen();
@@ -189,11 +196,6 @@ MainWindow.prototype = {
             return true;
         }
 
-        if (keyval == Gdk.KEY_Escape && fullscreen) {
-            Global.modeController.setFullscreen(false);
-            return true;
-        }
-
         if (keyval == Gdk.KEY_Escape ||
             keyval == Gdk.KEY_Back) {
             Global.modeController.setWindowMode(WindowMode.WindowMode.OVERVIEW);
@@ -207,18 +209,12 @@ MainWindow.prototype = {
         let keyval = event.get_keyval()[1];
 
         if (Utils.isSearchEvent(event)) {
-            let visible = Global.searchController.getSearchVisible();
-            Global.searchController.setSearchVisible(!visible);
+            this._searchbar.toggle();
             return true;
         }
 
-        if (!Global.searchController.getSearchIn()) {
-            Global.searchController.deliverEvent(event);
-            let handled = Global.searchController.getEventHandled();
-
-            if (handled)
-                return true;
-        }
+        if (this._searchbar.deliverEvent(event))
+            return true;
 
         if (Global.selectionController.getSelectionMode() &&
             keyval == Gdk.KEY_Escape) {
@@ -250,7 +246,7 @@ MainWindow.prototype = {
                                 'Florian M' + String.fromCharCode(0x00FC) + 'llner <fmuellner@gnome.org>',
                                 'William Jon McCann <william.jon.mccann@gmail.com>' ];
         aboutDialog.translator_credits = _("translator-credits");
-        aboutDialog.program_name = _("GNOME Documents");
+        aboutDialog.program_name = _("Documents");
         aboutDialog.comments = _("A document manager application");
         aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2011' + String.fromCharCode(0x2013) + '2012 Red Hat, Inc.';
         aboutDialog.license_type = Gtk.License.GPL_2_0;
