@@ -21,6 +21,7 @@
 
 const EvView = imports.gi.EvinceView;
 const Gd = imports.gi.Gd;
+const Gdk = imports.gi.Gdk;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const GtkClutter = imports.gi.GtkClutter;
@@ -430,15 +431,11 @@ OrganizeCollectionModel.prototype = {
         }
     },
 
-    getPlaceholder: function(forget) {
-        let ret = null;
+    forgetPlaceholder: function() {
+        let path = this._placeholderRef.get_path();
+        this._placeholderRef = null;
 
-        if (this._placeholderRef)
-            ret = this._placeholderRef.get_path();
-        if (forget)
-            this._placeholderRef = null;
-
-        return ret;
+        return path;
     },
 
     destroy: function() {
@@ -460,8 +457,6 @@ function OrganizeCollectionView() {
 
 OrganizeCollectionView.prototype = {
     _init: function() {
-        this._choiceConfirmed = false;
-
         this._model = new OrganizeCollectionModel();
         this.widget = new Gtk.TreeView({ headers_visible: false,
                                          vexpand: true,
@@ -521,7 +516,7 @@ OrganizeCollectionView.prototype = {
             return;
         }
 
-        let path = this._model.getPlaceholder(true);
+        let path = this._model.forgetPlaceholder();
         if (!path)
             return;
 
@@ -532,7 +527,7 @@ OrganizeCollectionView.prototype = {
         job.run(null);
     },
 
-    _onTextEditedReal: function(cell, path, newText) {
+    _onTextEdited: function(cell, pathStr, newText) {
         cell.editable = false;
 
         if (!newText || newText == '') {
@@ -542,30 +537,17 @@ OrganizeCollectionView.prototype = {
         }
 
         // update the new name immediately
+        let path = Gtk.TreePath.new_from_string(pathStr);
         let iter = this._model.model.get_iter(path)[1];
         this._model.model.set_value(iter, OrganizeModelColumns.NAME, newText);
 
         // actually create the new collection
         let job = new CreateCollectionJob(newText);
-        job.run(Lang.bind(this, this._onNewCollectionCreated));
+        job.run(Lang.bind(this, this._onNewCollectionCreated, path));
     },
 
-    _onTextEdited: function(cell, pathStr, newText) {
-        this._onTextEditedReal(cell, Gtk.TreePath.new_from_string(pathStr), newText);
-    },
-
-    _onTextEditCanceled: function(cell) {
-        if (this._choiceConfirmed) {
-            this._choiceConfirmed = false;
-
-            let entry = this._viewCol.cell_area.get_edit_widget();
-            let path = this._model.getPlaceholder(false);
-
-            if (entry && path)
-                this._onTextEditedReal(cell, path, entry.get_text());
-        } else {
-            this._model.removePlaceholder();
-        }
+    _onTextEditCanceled: function() {
+        this._model.removePlaceholder();
     },
 
     _checkCellFunc: function(col, cell, model, iter) {
@@ -598,10 +580,6 @@ OrganizeCollectionView.prototype = {
 
         this._rendererText.editable = true;
         this.widget.set_cursor_on_cell(path, this._viewCol, this._rendererText, true);
-    },
-
-    confirmedChoice: function() {
-        this._choiceConfirmed = true;
     }
 };
 
@@ -622,7 +600,7 @@ OrganizeCollectionDialog.prototype = {
                                        default_height: 250 });
 
         this.widget.add_button('gtk-add', OrganizeCollectionDialogResponse.ADD);
-        let okButton = this.widget.add_button('gtk-ok', Gtk.ResponseType.OK);
+        this.widget.add_button('gtk-ok', Gtk.ResponseType.OK);
         this.widget.set_default_response(Gtk.ResponseType.OK);
 
         let contentArea = this.widget.get_content_area();
@@ -635,20 +613,6 @@ OrganizeCollectionDialog.prototype = {
         sw.add(collView.widget);
         contentArea.add(sw);
 
-        // HACK:
-        // - We want clicking on "OK" to add the typed-in collection if we're editing.
-        // - Unfortunately, since we focus out of the editable entry in order to
-        //   click the button, we'll get an editing-canceled signal on the renderer
-        //   from GTK. As this handler will run before focus-out, we here signal the
-        //   view to ignore the next editing-canceled signal and add the collection in
-        //   that case instead.
-        //
-        okButton.connect('button-press-event', Lang.bind(this,
-            function() {
-                collView.confirmedChoice();
-                return false;
-            }));
-
         this.widget.connect('response', Lang.bind(this,
             function(widget, response) {
                 if (response == OrganizeCollectionDialogResponse.ADD)
@@ -736,17 +700,17 @@ SelectionToolbar.prototype = {
 
         this.widget = new Gtk.Toolbar({ show_arrow: false,
                                         icon_size: Gtk.IconSize.LARGE_TOOLBAR });
+        this.widget.get_style_context().add_class('osd');
 
         this.actor = new GtkClutter.Actor({ contents: this.widget,
                                             show_on_set_parent: false,
                                             opacity: 0 });
-        let actorWidget = this.actor.get_widget();
-        actorWidget.get_style_context().add_class('documents-osd');
-        actorWidget.reset_style();
+        Utils.alphaGtkWidget(this.actor.get_widget());
 
         this._leftBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
         this._leftGroup = new Gtk.ToolItem({ child: this._leftBox });
         this.widget.insert(this._leftGroup, -1);
+        this._leftGroup.show_all();
 
         this._toolbarFavorite = new Gtk.ToggleButton({ child: new Gtk.Image ({ icon_name: 'emblem-favorite-symbolic',
                                                                                pixel_size: 32 })});
@@ -766,6 +730,7 @@ SelectionToolbar.prototype = {
         this._rightBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
         this._rightGroup = new Gtk.ToolItem({ child: this._rightBox });
         this.widget.insert(this._rightGroup, -1);
+        this._rightGroup.show_all();
 
         this._toolbarCollection = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'list-add-symbolic',
                                                                            pixel_size: 32 })});
@@ -785,7 +750,7 @@ SelectionToolbar.prototype = {
         this._rightBox.add(this._toolbarOpen);
         this._toolbarOpen.connect('clicked', Lang.bind(this, this._onToolbarOpen));
 
-        this.widget.show_all();
+        this.widget.show();
 
         Global.selectionController.connect('selection-mode-changed',
                                            Lang.bind(this, this._onSelectionModeChanged));
@@ -834,9 +799,8 @@ SelectionToolbar.prototype = {
         let apps = [];
         let favCount = 0;
         let showFavorite = true;
-        let showTrash = true;
-        let showPrint = true;
-        let showOpen = true;
+        let canTrash = true;
+        let showPrint = false;
 
         this._insideRefresh = true;
 
@@ -852,15 +816,27 @@ SelectionToolbar.prototype = {
                     (apps.indexOf(doc.defaultAppName) == -1))
                     apps.push(doc.defaultAppName);
 
-                showTrash &= doc.canTrash();
-                showPrint &= !doc.collection;
+                if (!doc.canTrash())
+                    canTrash = false;
             }));
 
         showFavorite &= ((favCount == 0) || (favCount == selection.length));
-        showOpen = (apps.length > 0);
 
-        if (selection.length > 1)
-            showPrint = false;
+        if (selection.length == 1) {
+            let urn = selection[0];
+            if (!Global.collectionManager.getItemById(urn))
+                showPrint = true;
+        }
+
+        if (showPrint)
+            this._toolbarPrint.show_all();
+        else
+            this._toolbarPrint.hide();
+
+        if (canTrash)
+            this._toolbarTrash.show_all();
+        else
+            this._toolbarTrash.hide();
 
         let openLabel = null;
         if (apps.length == 1) {
@@ -870,7 +846,11 @@ SelectionToolbar.prototype = {
             // Translators: this is the Open action in a context menu
             openLabel = _("Open");
         }
-        this._toolbarOpen.set_tooltip_text(openLabel);
+
+        if (apps.length > 0) {
+            this._toolbarOpen.set_tooltip_text(openLabel);
+            this._toolbarOpen.show_all();
+        }
 
         if (showFavorite) {
             let isFavorite = (favCount == selection.length);
@@ -879,22 +859,20 @@ SelectionToolbar.prototype = {
             if (isFavorite) {
                 favoriteLabel = _("Remove from favorites");
                 this._toolbarFavorite.set_active(true);
-                this._toolbarFavorite.get_style_context().add_class('favorite');
+                this._toolbarFavorite.get_style_context().add_class('documents-favorite');
             } else {
                 favoriteLabel = _("Add to favorites");
                 this._toolbarFavorite.set_active(false);
-                this._toolbarFavorite.get_style_context().remove_class('favorite');
+                this._toolbarFavorite.get_style_context().remove_class('documents-favorite');
             }
 
             this._toolbarFavorite.reset_style();
             this._toolbarFavorite.set_tooltip_text(favoriteLabel);
+            this._toolbarFavorite.show_all();
+        } else {
+            this._toolbarFavorite.hide();
         }
 
-        this._toolbarPrint.set_visible(showPrint);
-        this._toolbarTrash.set_visible(showTrash);
-        this._toolbarOpen.set_visible(showOpen);
-        this._toolbarFavorite.set_visible(showFavorite);
-
         this._insideRefresh = false;
     },
 
